Installation
============

Prerequisites
^^^^^^^^^^^^^

This package has the following prerequisites:

* simplejson 
* versiontools

To run the test suite you will also need:

* testtools
* testscenarios

To build the documentation from source you will also need:

* sphinx

Installation Options
^^^^^^^^^^^^^^^^^^^^

There are several installation options available:

Using Ubuntu PPAs
-----------------

For Ubuntu 10.04 onward there is a stable and unstable PPA (personal package
archives):

* ppa:linaro-infrastructure/launch-control
* ppa:linaro-infrastructure/launch-control-snapshots

The stable PPA has normal releases, the unstable PPA has daily development
snapshots and is not recommended unless you need a bleeding edge feature. To
add a ppa to an Ubuntu system use the add-apt-repository command::

    sudo add-apt-repository ppa:linaro-infrastructure/launch-control

After you add the PPA you need to update your package cache::

    sudo apt-get update

Finally you can install the package, it is called `python-linaro-json`::

    sudo apt-get install python-linaro-json


Using Python Package Index
--------------------------

This package is being actively maintained and published in the `Python Package
Index <http://http://pypi.python.org>`_. You can install it if you have `pip
<http://pip.openplans.org/>`_ tool using just one line::

    pip install linaro-json


Using source tarball
--------------------

To install from source you must first obtain a source tarball from either pypi
or from `Launchpad <http://launchpad.net/>`_. To install the package unpack the
tarball and run::

    python setup.py install

You can pass ``--user`` if you prefer to do a local (non system-wide) installation.

..  note:: 

    To install from source you will need distutils (replacement of setuptools)
    They are typically installed on any Linux system with python but on Windows
    you may need to install that separately.
